/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import org.apache.commons.lang.StringUtils;

public class JavaEntities {
  public static final String QUALIFIER_JAVA_MAIN = "JMA";
  public static final String QUALIFIER_JAVA_UNIT_TEST = "JUN";

  public static final String DEFAULT_PACKAGE_NAME = "[default]";

  public static MavenProject newPackage(String projectKey, String name, Integer projectId) {
    String packageName = parsePackageName(name);
    return new MavenProject(MavenProject.SCOPE_PACKAGE, projectKey + ":" + packageName, null, projectId, packageName);
  }

  public static MavenProject newClass(String projectKey, String packageName, String className, boolean unitTest, Integer projectId) {
    String pureClassName = StringUtils.substringBefore(className, ".").trim();

    StringBuilder sb = new StringBuilder();
    sb.append(projectKey).append(":").append(parsePackageName(packageName)).append(".").append(pureClassName);
    return new MavenProject(MavenProject.SCOPE_CLASS, sb.toString(), getJavaQualifier(unitTest), projectId, pureClassName);
  }

  public static String getJavaQualifier(boolean unitTest) {
    if (unitTest) {
      return QUALIFIER_JAVA_UNIT_TEST;
    }
    return QUALIFIER_JAVA_MAIN;
  }

  private static String parsePackageName(String packageName) {
    if (packageName==null || "".equals(packageName.trim())) {
      return DEFAULT_PACKAGE_NAME;
    }
    return packageName.trim();
  }
}
