/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;
import org.hibernate.annotations.Immutable;

import javax.persistence.*;

@Immutable
@Cache(usage = CacheConcurrencyStrategy.READ_ONLY)
@Entity
@Table(name = "rules")
@NamedQueries(
    {@NamedQuery(name = Rule.SQL_SELECT_ALL, query = "SELECT r FROM Rule r")}
)
public class Rule {
  public final static String SQL_SELECT_ALL = "Rule.selectAll";

  @Id
  @Column(name = "id")
  @SequenceGenerator(name= "RULES_SEQ", sequenceName = "RULES_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "RULES_SEQ")
  private Integer id;

  @Column(name = "name", updatable = false, nullable = false)
  private String name;

  @Column(name = "plugin_rule_key", updatable = false, nullable = true)
  private String pluginRuleKey;
  
  @Column(name = "plugin_config_key", updatable = false, nullable = true)
  private String pluginConfigKey;

  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "rules_category_id", updatable = false, nullable = false)
  @Cache(usage = CacheConcurrencyStrategy.READ_ONLY)
  private RulesCategory rulesCategory;

  @Column(name = "plugin_name", updatable = false, nullable = true)
  private String pluginName;

  public Rule() {
  }

  public Rule(String name, String pluginRuleKey, RulesCategory rulesCategory, String pluginName) {
    this.name = name;
    this.pluginRuleKey = pluginRuleKey;
    this.rulesCategory = rulesCategory;
    this.pluginName = pluginName;
  }
  
  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public String getPluginRuleKey() {
    return pluginRuleKey;
  }

  public void setPluginRuleKey(String pluginRuleKey) {
    this.pluginRuleKey = pluginRuleKey;
  }

  public RulesCategory getRulesCategory() {
    return rulesCategory;
  }

  public void setRulesCategory(RulesCategory rulesCategory) {
    this.rulesCategory = rulesCategory;
  }

  public String getPluginName() {
    return pluginName;
  }

  public void setPluginName(String pluginName) {
    this.pluginName = pluginName;
  }
  
  public String getPluginConfigKey() {
    return pluginConfigKey;
  }

  public void setPluginConfigKey(String pluginConfigKey) {
    this.pluginConfigKey = pluginConfigKey;
  }

  public boolean equals(Object obj) {
    if (!(obj instanceof Rule)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    Rule other = (Rule) obj;
    return new EqualsBuilder()
        .append(id, other.getId()).isEquals();
  }

  public int hashCode() {
    return new HashCodeBuilder(17, 37).
        append(id).toHashCode();
  }
  
  public String toString() {
    return id.toString().concat( ":" ).concat( name );
  }

}
