/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;

import javax.persistence.*;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

@Entity
@Table(name = "rules_profiles")
public class RulesProfile implements Serializable {
  @Id
  @Column(name = "id")
  @SequenceGenerator(name = "RULES_PROFILES_SEQ", sequenceName = "RULES_PROFILES_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "RULES_PROFILES_SEQ")
  private Integer id;

  @Column(name = "name", updatable = false, nullable = false)
  private String name;

  @Column(name = "active", updatable = true, nullable = false)
  private Boolean active;

  @OneToMany(mappedBy = "rulesProfile", fetch = FetchType.LAZY, cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REMOVE})
  private List<ActiveRule> activeRules;

  public RulesProfile() {
  }

  public RulesProfile(String name, boolean active) {
    this.name=name;
    this.active=active;
  }

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public List<ActiveRule> getActiveRules() {
    return activeRules;
  }

  public void setActiveRules(List<ActiveRule> activeRules) {
    this.activeRules = activeRules;
  }

  public Boolean getActive() {
    return active;
  }

  public void setActive(Boolean active) {
    this.active = active;
  }

  public boolean equals(Object obj) {
    if (!(obj instanceof RulesProfile)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    RulesProfile other = (RulesProfile) obj;
    return new EqualsBuilder()
        .append(id, other.getId()).isEquals();
  }

  public int hashCode() {
    return new HashCodeBuilder(17, 37).
        append(id).toHashCode();
  }

  public List<ActiveRule> getActiveRules(RuleFailureLevel level) {
    List<ActiveRule> result = new ArrayList<ActiveRule>();
    for(ActiveRule activeRule:getActiveRules()) {
      if(activeRule.getLevel().equals(level)) {
        result.add(activeRule);
      }
    }
    return result;
  }
}
