/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.service;

import ch.hortis.sonar.model.*;
import org.sonar.commons.database.DatabaseManager;

import javax.persistence.Query;
import java.util.*;

public class MeasuresDao {

  private DatabaseManager databaseManager;

  public MeasuresDao(DatabaseManager databaseManager) {
    this.databaseManager = databaseManager;
  }

  public List<ProjectMeasure> getMeasures(Integer snapshotId) {
    Query query = databaseManager.createQuery(
      "SELECT m from " + ProjectMeasure.class.getSimpleName() + " m where m.snapshotId=:snapshotId");
    query.setParameter("snapshotId", snapshotId);
    return query.getResultList();
  }

  public Snapshot getSnapshot(int snapshotId) {
    Query query = databaseManager.createQuery(
      "SELECT s FROM " + Snapshot.class.getSimpleName() + " s WHERE s.id=:id");
    query.setParameter("id", snapshotId);
    return (Snapshot) query.getSingleResult();
  }

  public String getSnapshotProjectName(int snapshotId) {
    Query query = databaseManager.createQuery(
      "SELECT p.name FROM " + MavenProject.class.getSimpleName() + " p, Snapshot s WHERE s.mavenProject=p AND s.id=:id");
    query.setParameter("id", snapshotId);
    return (String) query.getSingleResult();
  }

  public List<Snapshot> getChildSnapshots(Snapshot snapshot, boolean includeSubmodules) {
    List<Snapshot> result = new ArrayList<Snapshot>();
    Query query = databaseManager.createQuery(
      "SELECT s FROM " + Snapshot.class.getSimpleName() + " s WHERE s.parent = :parent");
    query.setParameter("parent", snapshot);
    List<Snapshot> childrens = query.getResultList();
    result.addAll(childrens);
    if (includeSubmodules) {
      for (Snapshot child : childrens) {
        List<Snapshot> subchildrens = getChildSnapshots(child, true);
        result.addAll(subchildrens);
      }
    }
    return result;
  }
}
