/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.commons;

import ch.hortis.sonar.model.Metric;
import org.sonar.commons.database.DatabaseManager;

import javax.persistence.Query;
import java.util.Collection;
import java.util.List;
import java.util.ArrayList;

public class ReadOnlyMetricsRepository implements MetricsRepository {
  private DatabaseManager databaseManager;

  public ReadOnlyMetricsRepository(DatabaseManager databaseManager) {
    this.databaseManager = databaseManager;
  }

  public Metric getMetric(Metric metric) {
    return (Metric) databaseManager.createQuery("select m from Metric m where m.name=:name").
      setParameter("name", metric.getName()).
      getSingleResult();
  }

  public Collection<Metric> getMetrics() {
    Query query = databaseManager.createQuery("SELECT m FROM Metric m ");
    return query.getResultList();
  }

  public List<Metric> getTendenciableMetrics() {
    List<Metric> result = new ArrayList<Metric>();
    for (Metric metric : getMetrics()) {
      if (metric.isTendencyable()) {
        result.add(metric);
      }
    }
    return result;
  }
}
